@@ -6,7 +6,7 @@ our $AUTHORITY = 'cpan:GENE';
 use strict;
 use warnings;
 
-our $VERSION = '0.0100';
+our $VERSION = '0.0101';
 
 use Encode qw(encode_utf8);
 use Crypt::Passphrase::Bcrypt;
@@ -62,11 +62,12 @@ DBIx::Class::EncodedColumn::Crypt::Passphrase::Bcrypt - Crypt::Passphrase::Bcryp
 
 =head1 VERSION
 
-version 0.0100
+version 0.0101
 
 =head1 SYNOPSIS
 
-  # Crypt::Passphrase::Bcrypt / cost of 6 / generate check method
+  # Crypt::Passphrase::Bcrypt / cost of 6 / generate check method:
+
   __PACKAGE__->add_columns(
     password => {
       data_type           => 'CHAR',
@@ -74,7 +75,7 @@ version 0.0100
       encode_column       => 1,
       encode_class        => 'Crypt::Passphrase::Bcrypt',
       encode_args         => { cost => 6 },
-      encode_check_method => 'verify_password',
+      encode_check_method => 'check_password',
   });
 
 =head1 DESCRIPTION
